@@ -19,22 +19,24 @@ def build_dataloader(dataset: Dataset,
                      shuffle: bool = True,
                      persistent_workers: bool = True,
                      phase: str = "train",
+                     distributed=True,
                      **kwargs) -> DataLoader:
     """
-    :param dataset:
+    :param dataset: Dataset
     :param batch_size:
     :param num_workers:
     :param shuffle:
     :param persistent_workers:如为False，数据加载器运行完一个Epoch后会关闭worker进程,
                               在分布式训练，会出现每个epoch初始化多进程的问题
                               如果为True，会保持worker进程实例激活状态
-    :param phase:
+    :param phase: "train", "test", "val"
+    :param distributed: True: use DDP; False: use DP (是否使用分布式训练)
     :param kwargs:
     :return:
     """
     assert phase in ["train", "test", "val"]
     sampler = None
-    if comm.get_world_size() > 1 and phase == "train":
+    if comm.get_world_size() > 1 and phase == "train" and distributed:
         sampler = torch_utils.distributed.DistributedSampler(dataset,
                                                              num_replicas=comm.get_world_size(),
                                                              rank=comm.get_local_rank(),
@@ -60,17 +62,19 @@ def build_dataloader(dataset: Dataset,
 
 def build_model_parallel(model: nn.Module,
                          device_ids=None,
+                         distributed=True,
                          **kwargs) -> nn.Module:
     """
     :param model:
     :param device_ids:
+    :param distributed: True: use DDP; False: use DP (是否使用分布式训练)
     :param kwargs:
     :return:
     """
     print("device_ids:{},device:{}".format(device_ids, comm.get_device(device_ids)))
     model.to(comm.get_device(device_ids))
     # use DistributedDataParallel
-    if comm.get_world_size() > 1:
+    if comm.get_world_size() > 1 and distributed:
         model = nn.parallel.DistributedDataParallel(model,
                                                     device_ids=[comm.get_device(device_ids)],
                                                     output_device=comm.get_device(device_ids),
